@@ -362,26 +362,75 @@ class PSquared(object):
         raise FatalError('Configuration "' + name + '" is not available from "' + application.find('uri').text  + '"', 1, ET.tostring(application))
 
 
-    def get_configuration(self, name):
-        """:param str name: the name of the configuration whose URL should be returned.
+    def _prepare_query(self, options = None):
+        query = ''
+        if None != options and 0 != len(options):
+            conjunction = '?'
+            for key, value in options.items():
+                query = query + conjunction + key + '=' + value
+        return query
+
+
+    def get_configuration(self, name, options = None):
+        """:param str name: the name of the configuration that should be returned.
+        :param options: an optional dictionary of options determining how much detail to include in the returned configuration.
 
         :return: the configuration document the named configuration.
         :rtype: ElementTree
 
-        :raises FatalError: if the server response in not OK.
+        :raises FatalError: if the server response is not OK.
         """
 
         configuration_url, application = self._get_configuration_url(name)
-        r = self.session.get(configuration_url)
-        _check_status(configuration_url, r, 200)
+        url_to_use = configuration_url + self._prepare_query(options)
+        r = self.session.get(url_to_use)
+        _check_status(url_to_use, r, 200)
         configuration = ET.fromstring(r.text)
-        self._pretty_print(configuration_url, ET.tostring(configuration))
+        self._pretty_print(url_to_use, ET.tostring(configuration))
         return configuration, application
 
 
-    def _get_named_resource_url(self, config, version, xpath, name):
+    def get_version(self, config, vers = None, options = None):
+        """:param str config: the name of the configuration who version should be returned.
+        :param str vers: the name of the version of the specified configuration to be returned.
+        :param options: an optional dictionary of options determining how much detail to include in the returned version.
+
+        :return: the version document the named configuration/version.
+        :rtype: ElementTree
+
+        :raises FatalError: if the server response is not OK.
+        """
+
+        configuration, application = self.get_configuration(config)
+        url = application.find('uri').text
+        if None == vers:
+            v = configuration.find('default-version')
+            if None != v and None != v.text:
+                default_version = configuration.findall('known-versions/known-version/[uri="' + v.text + '"]')
+
+                if None != default_version:
+                    vers_to_use = default_version.find('name').text
+                else:
+                    raise FatalError('Default version of configuration "' + config + '" is not available from ' + url, 1, None)
+            else:
+                raise FatalError('No default version of configuration "' + config + '" is not available from ' + url, 1, None)
+        else:
+            vers_to_use = vers
+        version_element = configuration.find('known-versions/known-version/[name="' + vers_to_use + '"]')
+        if None == version_element:
+            raise FatalError('Version "' + vers_to_use + '" of configuration "' + config + '" is not available from ' + url, 1, None)
+        version_url = version_element.find('uri').text
+        url_to_use = version_url + self._prepare_query(options)
+        r = self.session.get(url_to_use)
+        _check_status(url_to_use, r, 200)
+        version = ET.fromstring(r.text)
+        self._pretty_print(url_to_use, ET.tostring(version))
+        return version, configuration, application
+
+
+    def _get_named_resource_url(self, config, vers, xpath, name):
         """:param str config: the name of the configuration to which the Named Resource should belong.
-        :param str version: the version of the named configuration to which the Named Resource should belong.
+        :param str vers: the version of the named configuration to which the Named Resource should belong.
         :param str xpath: the xpath to the Named Resources within a Named Resource group that contains the Named Resource.
         :param str name: the name of theresource whose URL should be returned.
 
@@ -390,28 +439,12 @@ class PSquared(object):
                                                                                                                                                                        :raises FatalError: if the server response in not OK.
         """
 
-        configuration, application = self.get_configuration(config)
-        url = application.find('uri').text
-        if None == version:
-            v = configuration.find('default-version')
-            if None != v and None != v.text:
-                default_version = configuration.findall('known-versions/known-version/[uri="' + v.text + '"]')
-
-                if None != default_version:
-                    version_to_use = default_version.find('name').text
-                else:
-                    raise FatalError('Default version of configuration "' + config + '" is not available from ' + url, 1, None)
-            else:
-                raise FatalError('No default version of configuration "' + config + '" is not available from ' + url, 1, None)
-        else:
-            version_to_use = version
-        found_version = configuration.find('known-versions/known-version/[name="' + version_to_use + '"]')
-        if None == found_version:
-            raise FatalError('Version "' + version_to_use + '" of configuration "' + config + '" is not available from ' + url, 1, None)
-        cmd = found_version.find(xpath + '/[name="' + name + '"]')
+        version, configuration, application = self.get_version(config, vers)
+        version_in_use = version.find('name').text
+        cmd = version.find(xpath + '/[name="' + name + '"]')
         if None == cmd:
-            raise FatalError('The version, "' + version_to_use + '", of configuration "' + config + '" does not support the "' + name + '" command', 2, ET.tostring(found_version))
-        return cmd.find('uri').text, version_to_use, application
+            raise FatalError('The version, "' + version_in_use + '", of configuration "' + config + '" does not support the "' + name + '" command', 2, ET.tostring(found_version))
+        return cmd.find('uri').text, version_in_use, application
 
 
     def get_report(self, name, version, report, page = None, length = None, items = None):
